@@ -9,7 +9,7 @@ from moto.core.utils import camelcase_to_underscores, method_names_from_class
 class BaseResponse(object):
 
     def dispatch(self, request, full_url, headers):
-        querystring = None
+        querystring = {}
 
         if hasattr(request, 'body'):
             # Boto
@@ -27,11 +27,11 @@ class BaseResponse(object):
                 querystring[key] = [value, ]
 
         if not querystring:
-            querystring = parse_qs(urlparse(full_url).query)
+            querystring.update(parse_qs(urlparse(full_url).query))
         if not querystring:
-            querystring = parse_qs(self.body)
+            querystring.update(parse_qs(self.body))
         if not querystring:
-            querystring = headers
+            querystring.update(headers)
 
         self.uri = full_url
         self.path = urlparse(full_url).path
@@ -75,7 +75,13 @@ def metadata_response(request, full_url, headers):
         Expiration=tomorrow.strftime("%Y-%m-%dT%H:%M:%SZ")
     )
 
-    path = parsed_url.path.lstrip("/latest/meta-data/")
+    path = parsed_url.path
+
+    meta_data_prefix = "/latest/meta-data/"
+    # Strip prefix if it is there
+    if path.startswith(meta_data_prefix):
+        path = path[len(meta_data_prefix):]
+
     if path == '':
         result = 'iam'
     elif path == 'iam':
